@@ -1,3 +1,5 @@
+from __future__ import absolute_import
+
 import base64
 try:
     import cPickle as pickle
@@ -21,8 +23,14 @@ logger = logging.getLogger('sentry.errors')
 
 class SentryClient(object):
     def process(self, **kwargs):
+        "Processes the message before passing it on to the server"
         from sentry.helpers import get_filters
 
+        if kwargs.get('data'):
+            # Ensure we're not changing the original data which was passed
+            # to Sentry
+            kwargs['data'] = kwargs['data'].copy()
+
         request = kwargs.pop('request', None)
         if request:
             if not kwargs.get('data'):
@@ -98,9 +106,16 @@ class SentryClient(object):
 
         self.send(**kwargs)
         
+        if request:
+            # attach the sentry object to the request
+            request.sentry = {
+                'id': message_id,
+            }
+        
         return message_id
 
     def send(self, **kwargs):
+        "Sends the message to the server."
         if conf.REMOTE_URL:
             for url in conf.REMOTE_URL:
                 data = {
@@ -125,10 +140,10 @@ class SentryClient(object):
 
     def create_from_record(self, record, **kwargs):
         """
-        Creates an error log for a `logging` module `record` instance.
+        Creates an error log for a ``logging`` module ``record`` instance.
         """
-        for k in ('url', 'view', 'data', 'request'):
-            if k not in kwargs:
+        for k in ('url', 'view', 'request', 'data'):
+            if not kwargs.get(k):
                 kwargs[k] = record.__dict__.get(k)
         
         kwargs.update({
@@ -156,7 +171,7 @@ class SentryClient(object):
 
     def create_from_text(self, message, **kwargs):
         """
-        Creates an error log for from ``type`` and ``message``.
+        Creates an error log for from ``message``.
         """
         return self.process(
             message=message,
@@ -247,3 +262,7 @@ class SentryClient(object):
             **kwargs
         )
 
+class DummyClient(SentryClient):
+    "Sends messages into an empty void"
+    def send(self, **kwargs):
+        return None
